@@ -1,7 +1,6 @@
 import numpy as np
 import pandas as pd
 from sklearn.linear_model import LinearRegression
-import warnings
 
 
 class Model:
@@ -96,10 +95,8 @@ class Model:
             else:
                 raise ValueError("Supplied dataset is not a pandas dataframe.")
             if dependent_df is not None:
-                warnings.warn("df argument is assuming the full regression "
-                              "dataset with the dependent variable and other "
-                              "regressors. Another value was passed as the "
-                              "dependent dataframe. Ignoring it.")
+                raise ValueError("Supplied dataset is not a pandas dataframe.")
+
 
         elif dependent_df is not None:
             if isinstance(dependent_df, pd.DataFrame):
