@@ -2,7 +2,7 @@ import os
 import numpy as np
 import pandas as pd
 import seaborn as sns
-from ChangePointModel import ChangePointModel
+from .ChangePointModel import ChangePointModel
 
 class NMEC:
     """
